function [objs,constrs]=TLN2obj_Mat(vars,NFEs)
% This is an example of the bi-objective design of Two-loop network.

% Input Vars:
%	(1) vars: decision variables (a 1-by-8 vector);
%	(2) NFEs: number of function evaluations (scalar);
% Output Vars:
%	(1) objs: objective values (a 1-by-2 vector);
%	(2) constrs: corresponding constraint violation (scalar);

% define local variables
diameterTable=[1 2 3 4 6 8 10 12 14 16 18 20 22 24];
costTable=[2 5 8 11 16 23 32 50 60 90 130 170 300 550];
errorCode=-1;
retrievedData=0.0;
juncElevation=zeros(6,1);
juncDemand=zeros(6,1);
juncHead=zeros(6,1);
minHead=zeros(6,1);
reservoirDischarge=0.0;
reservoirHead=0.0;
t=libpointer('longPtr',0);
tstep=libpointer('longPtr',3600);
% define objectives
objs=[0,0];
cost=0.0;
resilience=0.0;
constrs=0.0;
global numOfEvaluation
if isempty(numOfEvaluation)
    numOfEvaluation=1;
else
    numOfEvaluation=numOfEvaluation+1;
end
% open the hydraulic solver
if numOfEvaluation==1
    if ~libisloaded('epanet2')
        loadlibrary('epanet2.dll','epanet2.h');
    end
    calllib('epanet2','ENopen','TLN.inp','reportFile.rpt','');
    calllib('epanet2','ENopenH');
    calllib('epanet2','ENresetreport');
    calllib('epanet2','ENsetreport','MESSAGES NO');
    disp('The INP file has been opened.');
end
% convert the decision variables to integers
vars=floor(vars+1);
pipeDiameter=25.4*diameterTable(vars); % 1 inch=25.4 mm
% set pipe diameters and accumulate total cost
for i=1:8
    calllib('epanet2','ENsetlinkvalue',i,0,pipeDiameter(i)); % Diameter
    [~,retrievedData]=calllib('epanet2','ENgetlinkvalue',i,1,retrievedData); % Length
    cost=cost+costTable(vars(i))*retrievedData;
end
% solve the network equation
calllib('epanet2','ENinitH',0);
while get(tstep,'Value')~=0
    errorCode=calllib('epanet2','ENrunH',t);
    % get the demand and total head for each junction
    for i=1:6
        [~,juncElevation(i)]=calllib('epanet2','ENgetnodevalue',i,0,juncElevation(i)); % Elevation
        minHead(i)=30+juncElevation(i);
        [~,juncDemand(i)]=calllib('epanet2','ENgetnodevalue',i,9,juncDemand(i)); % Actual demand
        [~,juncHead(i)]=calllib('epanet2','ENgetnodevalue',i,10,juncHead(i)); % Hydraulic head
        [~,retrievedData]=calllib('epanet2','ENgetnodevalue',i,11,retrievedData); % Pressure
        if retrievedData<30.0
            constrs=constrs+(30.0-retrievedData);
        end
    end
    for i=1:1
        [~,reservoirDischarge]=calllib('epanet2','ENgetnodevalue',6+i,9,reservoirDischarge); % Actual demand
        [~,reservoirHead]=calllib('epanet2','ENgetnodevalue',6+i,10,reservoirHead); % Hydraulic head
    end
    calllib('epanet2','ENnextH',tstep);
end
% calculate the uniformity of the network
fromNode=zeros(1,8);
toNode=zeros(1,8);
juncU=zeros(1,6);
pipeIndex=[];
for i=1:8
    [~,fromNode(i),toNode(i)]=calllib('epanet2','ENgetlinknodes',i,fromNode(i),toNode(i));
end
for i=1:6
    nPipe=0;
    maxDiameter=0;
    sumDiameter=0;
    for j=1:8
        if fromNode(j)==i
            nPipe=nPipe+1;
            pipeIndex(nPipe)=j;
        end
        if toNode(j)==i
            nPipe=nPipe+1;
            pipeIndex(nPipe)=j;
        end
    end
    for k=1:nPipe
        [~,retrievedData]=calllib('epanet2','ENgetlinkvalue',pipeIndex(k),0,retrievedData); % diameter
        sumDiameter=sumDiameter+retrievedData;
        if retrievedData>maxDiameter
            maxDiameter=retrievedData;
        end
    end
    juncU(i)=sumDiameter/(nPipe*maxDiameter);
end
% calculate resilience
X=0.0;
Xmax=0.0;
for i=1:6
    X=X+juncU(i)*juncDemand(i)*(juncHead(i)-minHead(i));
    Xmax=Xmax+juncDemand(i)*minHead(i);
end
Xmax=-1*reservoirDischarge*reservoirHead-Xmax;
resilience=X/Xmax;
% calculate cost and violation
cost=cost/1e+006; % $ -> M$
objs=[cost,-resilience]; % both to minimise
constrs=constrs+errorCode;
constrs=-constrs;
% close the hydraulic solver
if numOfEvaluation==NFEs
    calllib('epanet2','ENcloseH');
    calllib('epanet2','ENclose');
    disp('The INP file has been closed.');
    numOfEvaluation=0;
    if libisloaded('epanet2')
        unloadlibrary('epanet2');
    end
end