function [objs,constrs]=objectiveFunction(vars,NFEs,problemDef,options)
% This function computes the values of objective functions and the
% corresponding constraint violation via MEX-files or generic M-files.

% Input Vars:
%	(1) vars: decision variables;
%	(2) NFEs: number of function evaluations;
%	(3) problemDef: definition of the target problem;
%	(4) options: a structure array containing the default settings of GALAXY
% Output Vars:
%	(1) objs: objective values;
%	(2) constrs: corresponding constraint violation;

% define local variables
popSize=size(vars,1);
objs=zeros(popSize,problemDef.NumOfObj);
constrs=zeros(popSize,1);
problemIndex=problemDef.Index;
% evaluate the objective functions using the MEX-files
if strcmpi(options.UseMex,'Yes')
    if problemIndex==1
        for i=1:popSize
            [objs(i,:),constrs(i)]=TRN2obj(vars(i,:),NFEs);
        end
    elseif problemIndex==2
        for i=1:popSize
            [objs(i,:),constrs(i)]=TLN2obj(vars(i,:),NFEs);
        end
    elseif problemIndex==3
        for i=1:popSize
            [objs(i,:),constrs(i)]=BAK2obj(vars(i,:),NFEs);
        end
    elseif problemIndex==4
        for i=1:popSize
            [objs(i,:),constrs(i)]=NYT2obj(vars(i,:),NFEs);
        end
    elseif problemIndex==5
        for i=1:popSize
            [objs(i,:),constrs(i)]=BLA2obj(vars(i,:),NFEs);
        end
    elseif problemIndex==6
        for i=1:popSize
            [objs(i,:),constrs(i)]=HAN2obj(vars(i,:),NFEs);
        end
    elseif problemIndex==7
        for i=1:popSize
            [objs(i,:),constrs(i)]=GOY2obj(vars(i,:),NFEs);
        end
    elseif problemIndex==8
        for i=1:popSize
            [objs(i,:),constrs(i)]=FOS2obj(vars(i,:),NFEs);
        end
    elseif problemIndex==9
        for i=1:popSize
            [objs(i,:),constrs(i)]=PES2obj(vars(i,:),NFEs);
        end
    elseif problemIndex==10
        for i=1:popSize
            [objs(i,:),constrs(i)]=MOD2obj(vars(i,:),NFEs);
        end
    elseif problemIndex==11
        for i=1:popSize
            [objs(i,:),constrs(i)]=BIN2obj(vars(i,:),NFEs);
        end
    elseif problemIndex==12
        for i=1:popSize
            [objs(i,:),constrs(i)]=EXN2obj(vars(i,:),NFEs);
        end
    end
elseif strcmpi(options.UseMex,'No') % using the generic functions
    if problemIndex==2
        for i=1:popSize
            [objs(i,:),constrs(i)]=TLN2obj_Mat(vars(i,:),NFEs);
        end
    end
end