function [problemDef]=problemArchive(input)
% This function returns the formulation of a specified benchmark WDS design problem.

% Input Vars:
%   input: enquiry input, the three-letter acronym (in upper case) of a certain benchmark problem, or the corresponding index;
% Output Vars:
%   problemDef: problem definition in the format of structure data type;

% =====Example Usage=====
% [problemDef]=problemArchive('TLN'); or
% [problemDef]=problemArchive(2);

% define local variables
problemIndex=0;
problemName='';
validStrings={'TRN','TLN','BAK','NYT','BLA','HAN','GOY','FOS','PES','MOD','BIN','EXN'};
problemDef=struct('Index',0,...
                  'Name','',...
				  'NumOfObj',0,...
				  'NumOfVar',0,...
				  'IsConstrained',0,...
				  'VarLowerBound',0,...
				  'VarUpperBound',0,...
				  'PF',[],...
                  'MaxCost',[],...
                  'Epsilon',[]);
% check the validity of input
if isnumeric(input) && length(input)==1
	problemIndex=input;
elseif ischar(input)
	problemName=validatestring(input,validStrings);
else
	disp('Your input is invalid. Please check carefully...');
    problemDef=[];
    return;
end
% define benchmark problems
if problemIndex==1 || strcmpi(problemName,'TRN')
	% -----Two-Reservoir Network-----
	problemDef.Index=1;
	problemDef.Name='TRN';
	problemDef.NumOfObj=2;
	problemDef.NumOfVar=8;
	problemDef.IsConstrained=1;
	problemDef.VarLowerBound=[0*ones(1,5),0*ones(1,3)];
	problemDef.VarUpperBound=[7*ones(1,5),9*ones(1,3)];
    load([pwd '/benchmark/best_known_PF/truePF_TRN'],'ParetoFront');
	problemDef.PF=ParetoFront;
elseif problemIndex==2 || strcmpi(problemName,'TLN')
	% -----Two-Loop Network-----
	problemDef.Index=2;
	problemDef.Name='TLN';
	problemDef.NumOfObj=2;
	problemDef.NumOfVar=8;
	problemDef.IsConstrained=1;
	problemDef.VarLowerBound=0*ones(1,8);
	problemDef.VarUpperBound=13*ones(1,8);
    load([pwd '/benchmark/best_known_PF/truePF_TLN'],'ParetoFront');
	problemDef.PF=ParetoFront;
elseif problemIndex==3 || strcmpi(problemName,'BAK')
	% -----BakRyan Network-----
	problemDef.Index=3;
	problemDef.Name='BAK';
	problemDef.NumOfObj=2;
	problemDef.NumOfVar=9;
	problemDef.IsConstrained=1;
	problemDef.VarLowerBound=0*ones(1,9);
	problemDef.VarUpperBound=10*ones(1,9);
    load([pwd '/benchmark/best_known_PF/truePF_BAK'],'ParetoFront');
	problemDef.PF=ParetoFront;
elseif problemIndex==4 || strcmpi(problemName,'NYT')
	% -----New York Tunnel Network-----
	problemDef.Index=4;
	problemDef.Name='NYT';
	problemDef.NumOfObj=2;
	problemDef.NumOfVar=21;
	problemDef.IsConstrained=1;
	problemDef.VarLowerBound=0*ones(1,21);
	problemDef.VarUpperBound=15*ones(1,21);
    load([pwd '/benchmark/best_known_PF/best-known_PF_NYT'],'bestKnown_PF');
	problemDef.PF=bestKnown_PF;
elseif problemIndex==5 || strcmpi(problemName,'BLA')
	% -----Blacksburg Network-----
	problemDef.Index=5;
	problemDef.Name='BLA';
	problemDef.NumOfObj=2;
	problemDef.NumOfVar=23;
	problemDef.IsConstrained=1;
	problemDef.VarLowerBound=0*ones(1,23);
	problemDef.VarUpperBound=13*ones(1,23);
    load([pwd '/benchmark/best_known_PF/best-known_PF_BLA'],'bestKnown_PF');
	problemDef.PF=bestKnown_PF;
elseif problemIndex==6 || strcmpi(problemName,'HAN')
	% -----Hanoi Network-----
	problemDef.Index=6;
	problemDef.Name='HAN';
	problemDef.NumOfObj=2;
	problemDef.NumOfVar=34;
	problemDef.IsConstrained=1;
	problemDef.VarLowerBound=0*ones(1,34);
	problemDef.VarUpperBound=5*ones(1,34);
    load([pwd '/benchmark/best_known_PF/best-known_PF_HAN'],'bestKnown_PF');
	problemDef.PF=bestKnown_PF;
elseif problemIndex==7 || strcmpi(problemName,'GOY')
	% -----GoYang Network-----
	problemDef.Index=7;
	problemDef.Name='GOY';
	problemDef.NumOfObj=2;
	problemDef.NumOfVar=30;
	problemDef.IsConstrained=1;
	problemDef.VarLowerBound=0*ones(1,30);
	problemDef.VarUpperBound=7*ones(1,30);
    load([pwd '/benchmark/best_known_PF/best-known_PF_GOY'],'bestKnown_PF');
	problemDef.PF=bestKnown_PF;
elseif problemIndex==8 || strcmpi(problemName,'FOS')
	% -----Fossolo Network-----
	problemDef.Index=8;
	problemDef.Name='FOS';
	problemDef.NumOfObj=2;
	problemDef.NumOfVar=58;
	problemDef.IsConstrained=1;
	problemDef.VarLowerBound=0*ones(1,58);
	problemDef.VarUpperBound=21*ones(1,58);
    load([pwd '/benchmark/best_known_PF/best-known_PF_FOS'],'bestKnown_PF');
	problemDef.PF=bestKnown_PF;
elseif problemIndex==9 || strcmpi(problemName,'PES')
	% -----Pescara Network-----
	problemDef.Index=9;
	problemDef.Name='PES';
	problemDef.NumOfObj=2;
	problemDef.NumOfVar=99;
	problemDef.IsConstrained=1;
	problemDef.VarLowerBound=0*ones(1,99);
	problemDef.VarUpperBound=12*ones(1,99);
    load([pwd '/benchmark/best_known_PF/best-known_PF_PES'],'bestKnown_PF');
	problemDef.PF=bestKnown_PF;
elseif problemIndex==10 || strcmpi(problemName,'MOD')
	% -----Modena Network-----
	problemDef.Index=10;
	problemDef.Name='MOD';
	problemDef.NumOfObj=2;
	problemDef.NumOfVar=317;
	problemDef.IsConstrained=1;
	problemDef.VarLowerBound=0*ones(1,317);
	problemDef.VarUpperBound=12*ones(1,317);
    load([pwd '/benchmark/best_known_PF/best-known_PF_MOD'],'bestKnown_PF');
	problemDef.PF=bestKnown_PF;
elseif problemIndex==11 || strcmpi(problemName,'BIN')
	% -----Balerma Irrigation Network-----
	problemDef.Index=11;
	problemDef.Name='BIN';
	problemDef.NumOfObj=2;
	problemDef.NumOfVar=454;
	problemDef.IsConstrained=1;
	problemDef.VarLowerBound=0*ones(1,454);
	problemDef.VarUpperBound=9*ones(1,454);
    load([pwd '/benchmark/best_known_PF/best-known_PF_BIN'],'bestKnown_PF');
	problemDef.PF=bestKnown_PF;
elseif problemIndex==12 || strcmpi(problemName,'EXN')
	% -----Exeter Network-----
	problemDef.Index=12;
	problemDef.Name='EXN';
	problemDef.NumOfObj=2;
	problemDef.NumOfVar=567;
	problemDef.IsConstrained=1;
	problemDef.VarLowerBound=0*ones(1,567);
	problemDef.VarUpperBound=10*ones(1,567);
    load([pwd '/benchmark/best_known_PF/best-known_PF_EXN'],'bestKnown_PF');
	problemDef.PF=bestKnown_PF;
else
	disp('This problem has not been defined yet. Please check carefully...');
    problemDef=[];
    return;
end
load([pwd '/benchmark/best_known_PF/maxCost'],'maxCost');
problemDef.MaxCost=maxCost(problemDef.Index);
load([pwd '/benchmark/best_known_PF/epsilonValue'],'epsilon');
problemDef.Epsilon=epsilon(problemDef.Index,:);